<?php 
/**
 * Custom theme functions.
 *
 * This file contains hook functions attached to theme hooks.
 *
 * @package shopeo
 */
if ( ! function_exists( 'shopeo_header' ) ) :
	function shopeo_header(){?>

<header class="nav-header">
	<div class="container">
		<div class="brand text-center mx-auto">
			<?php shopeo_site_logo(); ?>
			<?php shopeo_site_description();?>
		</div>
		<!--Navbar -->
		<nav class="navbar navbar-expand-lg navbar-light bg-theme">
			<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbar-collapse"
				aria-controls="navbar-collapse" aria-expanded="false"
				aria-label="<?php esc_attr_e( 'Toggle navigation', 'shopeo' ); ?>">
				<span class="toggle-menu fa fa-bars"></span>
			</button>
			<?php
			if ( has_nav_menu( 'primary' ) ) :
				wp_nav_menu( array(
					'theme_location'    => 'primary',
					'depth'             => 3,
					'container'         => 'div',
					'container_class'   => 'collapse navbar-collapse justify-content-center',
					'container_id'      => 'navbar-collapse',
					'menu_class'        => 'nav navbar-nav',
					'items_wrap'		=> '<ul class="nav navbar-nav" data-function="navbar">%3$s</ul>',
				) );
			else:
			wp_page_menu(
				array(
					'container'  => 'div',
					'menu_id'    => 'navbar-collapse',
					'menu_class' => 'nav navbar-nav',
					'menu_class' => 'collapse navbar-collapse justify-content-center',
					'before'     => '<ul class="nav navbar-nav" data-function="navbar">',
					'after'      => '</ul>',
				)
			); 
		 endif; 
		 ?>
		</nav><!--/navbar-->
	</div>
  
    
</header>
<?php
	}
endif;
add_action('shopeo_header','shopeo_header', 10);

/**
Footer hook function
**/
if ( ! function_exists( 'shopeo_footer' ) ) :
	function shopeo_footer(){?>
<!--Footer-->
<footer class="footer sec-bg">
    <div class="container">
        <div class="row text-left mt-4 mb-4">
		<?php
			if (is_active_sidebar('footer_menu')) {
				dynamic_sidebar('footer_menu');
			}
		?>
        </div>
        <hr>
        <div class="row copyright_info">
            <div class="col-md-12">
                <div class="mt-2">
                    <?php
					if (!is_active_sidebar('copyright')) {
					?>
                    <div class="footer-credits">
                        <p class="footer-copyright powered-by-wordpress">
                            &copy;
                            <?php
							echo date_i18n(
								/* translators: Copyright date format, see https://secure.php.net/date */
								_x( 'Y', 'copyright date format', 'shopeo' )
							);
							?>
									
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?>.</a>
							<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'shopeo' ) ); ?>">
							<?php _e( 'Powered by WordPress', 'shopeo' ); ?>
							</a>
                        </p><!-- .powered-by-wordpress -->
                    </div><!-- .footer-credits -->
                    <?php } else{?>
                    <small><?php dynamic_sidebar('copyright');?> </small>
                    <?php }?>
                </div>
            </div>
        </div>
    </div>
</footer>
<?php
	}
endif;
add_action('shopeo_action_footer','shopeo_footer', 10);

/** 
	Top Navbar
**/
function shopeo_top_navbar(){
	
	$shopeo_top_nav_enable = get_theme_mod('shopeo_top_nav_enable',0);
	if($shopeo_top_nav_enable==1) {
	?>
	<div class="top-bar-head">
		<div class="container">
			<div class="row"> 
				<div class="col-md-4">
				<?php 
				if ( has_nav_menu( 'top_nav' ) ) :
				wp_nav_menu( array(
					'theme_location'    => 'top_nav',
					'depth'             => 3,
					'container'         => 'div',
					'container_class'   => 'pull-left',
					'container_id'      => '',
					'menu_class'        => 'nav top-nav',
					'items_wrap'		=> '<ul class="top-nav">%3$s</ul>',
				) );	
				endif;
				?>
					
			</div>
			<div class="col-md-5">
			<?php
			$message 	= get_theme_mod('topbar_message','');
			?>
			<p class="text-center m-0 flush-msg">
				<?php echo esc_html($message); ?>
			</p>
			</div>
			<div class="col-md-3">
				<div class="topbar-socials pull-right">
						<?php 
						$facebook 	= get_theme_mod('facebook','');
						$twitter 	= get_theme_mod('twitter','');
						$linkedin 	= get_theme_mod('linkedin','');
						$pinterest 	= get_theme_mod('pinterest','');
						$instagram 	= get_theme_mod('instagram','');
						$email 		= get_theme_mod('email','');
						 ?>
						<ul class="social-icons clearfix">
							<?php if($facebook!=='') { ?>
							<li><a target="_blank" href="<?php echo esc_url($facebook); ?>"><i class="fa fa-facebook"></i></a></li>
							<?php }  if($twitter!=='') { ?>
							<li><a target="_blank" href="<?php echo esc_url($twitter); ?>"><i class="fa fa-twitter"></i></a></li>
							<?php }  if($linkedin!=='') { ?>
							<li><a target="_blank" href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin"></i></a></li>
							<?php }  if($pinterest!=='') {?>
							<li><a target="_blank" href="<?php echo esc_url($pinterest); ?>"><i class="fa fa-pinterest"></i></a></li>
							<?php } ?>
							<?php  if($instagram!=='') {?>
							<li><a target="_blank" href="<?php echo esc_url($instagram); ?>"><i class="fa fa-instagram"></i></a></li>
							<?php } ?>
							<?php if($email!=='') {?>
							<li><a target="_blank" href="mailto:<?php echo esc_url($email); ?>"><i class="fa fa-envelope"></i></a></li>
							<?php } ?>
						</ul>
					</div>
				</div>
			</div>
			<div class="clearfix"></div>	
			</div>
	</div>
		
	<?php } ?>
<?php }
add_action('shopeo_top_navbar','shopeo_top_navbar', 10);

// Author Box.
if ( ! function_exists( 'shopeo_author' ) ) :
function shopeo_author( $id ) {
	$id = $id ? $id : get_the_author_meta( 'ID' );
	?>
	<div class="row author-content">
		<div class="col-md-3">
			<?php echo get_avatar( $id, '164', '', '', array( 'class' => 'lazy-load' ) ); ?>
		</div>
		<div class="col-md-9">
			<h4 class="mb-2">
				<a href="<?php echo get_author_posts_url( $id ); ?>">
				<?php the_author_meta( 'display_name', $id ); ?>
				</a>
			</h4>
			<p>
			<?php the_author_meta( 'description', $id ); ?>
			</p>
			<?php if ( get_the_author_meta( 'url', $id ) !== '' ) { ?>
				<a href="<?php echo get_the_author_meta( 'url', $id ); ?>" target="_blank"><i class="fa fa-link"></i></a>
			<?php } ?>
		</div>
	</div>
	<?php if ( is_author() ):?>
		<div class="clearfix"></div>
		<h5 class="mt-5"><?php _e('Posts by','shopeo')?> 
			<?php the_author_meta( 'display_name', $id ); ?>:
		</h5>
		<hr>
	<?php
	endif;
}
endif;
add_action( 'shopeo_author', 'shopeo_author', 3 );

/* 
Preloader 
*/
function shopeo_preloader(){?>
	<div id="shopeo-loader" class="show fullscreen">
		<svg class="circular" width="48px" height="48px">
			<circle class="path-bg" cx="24" cy="24" r="22" fill="none" stroke-width="4" stroke="#eeeeee" />
			<circle class="path" cx="24" cy="24" r="22" fill="none" stroke-width="4" stroke-miterlimit="10"/>
		</svg>
	</div>
	<?php }
add_action('shopeo_preloader', 'shopeo_preloader');