<?php

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
/**
 * WC Theme Support.
 */
function shopeo_add_woocommerce_support() {

    add_theme_support( 'woocommerce', array(
        'thumbnail_image_width' => 300,
        'single_image_width'    => 300,

        'product_grid'          => array(
            'default_rows'    => 3,
            'min_rows'        => 2,
            'max_rows'        => 8,
            'default_columns' => 3,
            'min_columns'     => 2,
            'max_columns'     => 5,
        ),
    ) );

    add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );
}

add_action( 'after_setup_theme', 'shopeo_add_woocommerce_support' );

/**
 * Change number or products per row to 3
 */
add_filter('loop_shop_columns', 'shopeo_loop_columns', 999);
if (!function_exists('loop_columns')) {
	function shopeo_loop_columns() {
		return 3; // 3 products per row
	}
}

/**
 * unhook the WooCommerce wrappers.
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

add_action('woocommerce_before_main_content', 'shopeo_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'shopeo_wrapper_end', 10);

/**
 *  hook functions to display the wrappers.
 */

function shopeo_wrapper_start() {
    echo '<main id="site-content" class="site-main container">
    <div id="primary" class="content-area mt-5">';
}

function shopeo_wrapper_end() {
    echo ' </div><!-- #primary -->
	</main><!-- #main -->';
}


// WooCommerce Checkout Fields Hook
add_filter('woocommerce_checkout_fields','shopeo_wc_checkout_fields_no_label');


function shopeo_wc_checkout_fields_no_label($fields) {
    // loop by category
    foreach ( $fields as $category => $value ) {
        // loop by fields
        foreach ( $fields[$category] as $field => $property) {
            // remove label property
            $fields[ $category][$field]['placeholder'] = $fields[ $category][$field]['label'];
            unset( $fields[ $category][$field]['label'] );
        }
    }
    return $fields;
}

// Rearrange Checkout Sections
add_action( 'woocommerce_checkout_billing', 'shopeo_rearrange_sections' );
function shopeo_rearrange_sections() {
    $wc_checkout = new \WC_Checkout();
    
    remove_all_actions( 'woocommerce_checkout_shipping' );
    add_action('woocommerce_review_order_before_shipping','shopeo_add_title_before_review');
    add_action( 'woocommerce_checkout_shipping', 'woocommerce_checkout_payment', 20 );
    add_action( 'woocommerce_checkout_shipping', 'woocommerce_order_review', 10 );
    add_action( 'woocommerce_after_checkout_billing_form', [ $wc_checkout, 'checkout_form_shipping' ] );

    remove_action( 'woocommerce_checkout_order_review', 'woocommerce_order_review', 10 );
    remove_action( 'woocommerce_checkout_order_review', 'woocommerce_checkout_payment', 20 );
}


function shopeo_add_title_before_review(){?>
     <h3 id="order_review_title"><?php _e( 'Your order', 'shopeo' ); ?></h3>
<?php }


add_filter( 'woocommerce_show_page_title', 'shopeo_hide_shop_page_title' );
 
function shopeo_hide_shop_page_title( $title ) {
   if ( is_shop() ) $title = false;
   return $title;
}
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );

add_action( 'woocommerce_before_shop_loop_item_title', 'shopeo_loop_product_thumbnail', 10 );
function shopeo_loop_product_thumbnail() {
    global $product;
    $size = 'woocommerce_thumbnail';

    $image_size = apply_filters( 'single_product_archive_thumbnail_size', $size );

    echo $product ? $product->get_image( $image_size ) : '';
}

add_action( 'woocommerce_after_shop_loop_item', 'remove_add_to_cart_buttons', 1 );

    function remove_add_to_cart_buttons() {
      if( is_product_category() || is_shop()) { 
        remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart' );
      }
    }

 // Quantity Button Plus-Minus
    add_action( 'woocommerce_after_quantity_input_field', 'shopeo_display_quantity_plus' );
  
    function shopeo_display_quantity_plus() {
       echo '<button type="button" class="plus" >+</button>';
    }
      
    add_action( 'woocommerce_before_quantity_input_field', 'shopeo_display_quantity_minus' );
      
    function shopeo_display_quantity_minus() {
       echo '<button type="button" class="minus" >-</button>';
    }
      

    // Trigger update quantity script
      
    add_action( 'wp_footer', 'shopeo_add_cart_quantity_plus_minus' );
      
    function shopeo_add_cart_quantity_plus_minus() {
     
       if ( ! is_product() && ! is_cart() ) return;
        
       wc_enqueue_js( "   
               
       $(document).on('click','button.plus, button.minus',function(e){
 
        var qty = $( this ).parent( '.quantity' ).find( '.qty' );
        var val = parseFloat(qty.val());
        var max = parseFloat(qty.attr( 'max' ));
        var min = parseFloat(qty.attr( 'min' ));
        var step = parseFloat(qty.attr( 'step' ));
         
        $('.woocommerce .actions button.button').prop('disabled', false);
      
        if ( $( this ).is( '.plus' ) ) {
           if ( max && ( max <= val ) ) {
              qty.val( max );
           } else {
              qty.val( val + step );
           }
        } else {
           if ( min && ( min >= val ) ) {
              qty.val( min );
           } else if ( val > 1 ) {
              qty.val( val - step );
           }
        }
     });
            
       " );
    }
    

//end WC plugin activation Check
}